Code coverage report for js/components

# All files js/components

78.57% Statements 22/28
50% Branches 6/12
62.5% Functions 5/8
78.26% Lines 18/23

Press n or j to go to the next uncovered block, b, p or k for the previous block.

File |  | Statements |  | Branches |  | Functions |  | Lines |
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
RecordComponent.tsx |  | 50% | 6/12 | 25% | 2/8 | 25% | 1/4 | 50% | 5/10
ToggleGroup.tsx |  | 100% | 16/16 | 100% | 4/4 | 100% | 4/4 | 100% | 13/13